Version History
---------------

v0.2
""""

* start in a dir, looks for .rst files and serve them in html
* looks for index.rst at first and serve it
* if index.rst not found serve a page with the list of files
* simple edition (text area). Save and Cancel buttons
* git commit when saving


v0.1
""""

* first (non-working) version